/*
 * org.openmicroscopy.browser.datamodel.DataAttributeListener
 *
 *------------------------------------------------------------------------------
 *
 *  Copyright (C) 2004 Open Microscopy Environment
 *      Massachusetts Institute of Technology,
 *      National Institutes of Health,
 *      University of Dundee
 *
 *
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation; either
 *    version 2.1 of the License, or (at your option) any later version.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 *
 *    You should have received a copy of the GNU Lesser General Public
 *    License along with this library; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *------------------------------------------------------------------------------
 */




/*------------------------------------------------------------------------------
 *
 * Written by:    Jeff Mellen <jeffm@alum.mit.edu>
 *
 *------------------------------------------------------------------------------
 */
package org.openmicroscopy.browser.datamodel;

/**
 * Specifies a class that subscribes to change events in a data model.
 * 
 * @author Jeff Mellen, <a href="mailto:jeffm@alum.mit.edu">jeffm@alum.mit.edu</a>
 * <b>Internal version:</b> $Revision: 1.1 $ $Date: 2004/01/21 23:49:30 $
 * @version 2.2
 * @since 2.2
 */
public interface DataAttributeListener
{
  /**
   * An attribute changed event.
   * 
   * @param key The name of the changed attribute.
   */
  public void attributeChanged(String name);
  
  /**
   * An attribute added event.
   * @param name The name of this added attribute.
   */
  public void attributeAdded(String name);
  
  /**
   * An attribute removed event.
   * @param name The name of this removed attribute.
   */
  public void attributeRemoved(String name);
}
