
% Matlab manual stitcher
% This function calls the 
function sig_vec = SignatureChainTest(im_name);

% From Chebyshev Fourier Coefficients 1
im = double(imread(im_name));

% preparatory images
im_fft = FourierTransform(im); 
im_fft = im_fft(:,:,1); % extract the magnitude
im_gradient = Gradient(im);
im_bw = im2bw(im, graythresh(im));
[im_wav1, im_wav2] = WaveletSignatures(im);

[im_fft_wav1, im_fft_wav2] = WaveletSignatures(im_fft);
im_ccm = ChebyshevTransform(im);
im_ccm_fft = ChebyshevTransform(im_fft);

ChebyshevCoefficientHistogram_1 = ChebyshevStatistics(im);
ChebyshevCoefficientHistogram_2 = ChebyshevStatistics(im_fft);
ChebyshevFourierCoefficients_1 = ChebyshevFourierTransform(im);
ChebyshevFourierCoefficients_2 = ChebyshevFourierTransform(im_fft);

% Edge Statistics (computed of Gradient)
[EdgeArea, EdgeMagMean, EdgeMagMedian, EdgeMagVar, EdgeMagHist, ...
EdgeDirecMean, EdgeDirecMedian, EdgeDirecVar, EdgeDirecHist, ...
EdgeDirecHomo, EdgeDiffDirecHist] = EdgeStatistics(im_gradient);

% Feature Statistics (of binary image)
[FeatureCount, FeatureEuler, FeatureCentroid, FeatureAreaMin, ...
FeatureAreaMax, FeatureAreaMean, FeatureAreaMedian, FeatureAreaVar, ...
FeatureAreaHist, FeatureDistMin, FeatureDistMax, FeatureDistMean, ...
FeatureDistMedian, FeatureDistVar, FeatureDistHist] = FeatureStatistics(im_bw);

% zernike moments
ZernikeMoments = mb_zernike(im);

%%
%% Fresh -> "Haralick Features (Angle X)" 
%%

% Haralick Feature (Angle 0) is 32
[CoOcMat_AngularSecondMoment_32, CoOcMat_Contrast_32, CoOcMat_Correlation_32,   ...					
CoOcMat_Variance_32, CoOcMat_InverseDifferenceMoment_32, CoOcMat_SumAverage_32, ...
CoOcMat_SumVariance_32, CoOcMat_SumEntropy_32, CoOcMat_Entropy_32,			    ...
CoOcMat_DifferenceEntropy_32, CoOcMat_DifferenceVariance_32,		            ...	
CoOcMat_FirstMeasureOfCorrelation_32, CoOcMat_SecondMeasureOfCorrelation_32,    ...
CoOcMat_MaximalCorrelationCoefficient_32] = magic_split(mb_texture(im, 1, 0));

% Haralick Features (Angle 45)  is 18
[CoOcMat_AngularSecondMoment_18, CoOcMat_Contrast_18, CoOcMat_Correlation_18, 	...				
CoOcMat_Variance_18, CoOcMat_InverseDifferenceMoment_18, CoOcMat_SumAverage_18,	...
CoOcMat_SumVariance_18, CoOcMat_SumEntropy_18, CoOcMat_Entropy_18,				...
CoOcMat_DifferenceEntropy_18, CoOcMat_DifferenceVariance_18,			        ...
CoOcMat_FirstMeasureOfCorrelation_18, CoOcMat_SecondMeasureOfCorrelation_18,    ...
CoOcMat_MaximalCorrelationCoefficient_18] = magic_split(mb_texture(im, 1, 45));

% Haralick Features (Angle 90)  is 16
[CoOcMat_AngularSecondMoment_16, CoOcMat_Contrast_16, CoOcMat_Correlation_16, 	...			
CoOcMat_Variance_16, CoOcMat_InverseDifferenceMoment_16, CoOcMat_SumAverage_16,	...
CoOcMat_SumVariance_16, CoOcMat_SumEntropy_16, CoOcMat_Entropy_16,				...
CoOcMat_DifferenceEntropy_16, CoOcMat_DifferenceVariance_16,		        	...
CoOcMat_FirstMeasureOfCorrelation_16, CoOcMat_SecondMeasureOfCorrelation_16,    ...
CoOcMat_MaximalCorrelationCoefficient_16] = magic_split(mb_texture(im, 1, 90));

% Haralick Features (Angle 135) is 6
[CoOcMat_AngularSecondMoment_6, CoOcMat_Contrast_6, CoOcMat_Correlation_6, 	    ...				
CoOcMat_Variance_6, CoOcMat_InverseDifferenceMoment_6, CoOcMat_SumAverage_6,	...	
CoOcMat_SumVariance_6, CoOcMat_SumEntropy_6, CoOcMat_Entropy_6,				    ...	
CoOcMat_DifferenceEntropy_6, CoOcMat_DifferenceVariance_6,			            ...
CoOcMat_FirstMeasureOfCorrelation_6, CoOcMat_SecondMeasureOfCorrelation_6,      ...
CoOcMat_MaximalCorrelationCoefficient_6] = magic_split(mb_texture(im, 1, 135));

%%
%% Frequency -> "Haralick Features (Angle X) 1"
%%

% Haralick Feature (Angle 0)   1 is 26
[CoOcMat_AngularSecondMoment_26, CoOcMat_Contrast_26, CoOcMat_Correlation_26, 	...				
CoOcMat_Variance_26, CoOcMat_InverseDifferenceMoment_26, CoOcMat_SumAverage_26,	...	
CoOcMat_SumVariance_26, CoOcMat_SumEntropy_26, CoOcMat_Entropy_26,				...	
CoOcMat_DifferenceEntropy_26, CoOcMat_DifferenceVariance_26,			        ...
CoOcMat_FirstMeasureOfCorrelation_26, CoOcMat_SecondMeasureOfCorrelation_26,    ...
CoOcMat_MaximalCorrelationCoefficient_26] = magic_split(mb_texture(im_fft, 1, 0));

% Haralick Feature (Angle 45)  1 is 31
[CoOcMat_AngularSecondMoment_31, CoOcMat_Contrast_31, CoOcMat_Correlation_31, 	...				
CoOcMat_Variance_31, CoOcMat_InverseDifferenceMoment_31, CoOcMat_SumAverage_31,	...	
CoOcMat_SumVariance_31, CoOcMat_SumEntropy_31, CoOcMat_Entropy_31,				...	
CoOcMat_DifferenceEntropy_31, CoOcMat_DifferenceVariance_31,			        ...
CoOcMat_FirstMeasureOfCorrelation_31, CoOcMat_SecondMeasureOfCorrelation_31,    ...
CoOcMat_MaximalCorrelationCoefficient_31] = magic_split(mb_texture(im_fft, 1, 45));

% Haralick Feature (Angle 90)  1 is 22
[CoOcMat_AngularSecondMoment_22, CoOcMat_Contrast_22, CoOcMat_Correlation_22, 	...				
CoOcMat_Variance_22, CoOcMat_InverseDifferenceMoment_22, CoOcMat_SumAverage_22,	...	
CoOcMat_SumVariance_22, CoOcMat_SumEntropy_22, CoOcMat_Entropy_22,				...	
CoOcMat_DifferenceEntropy_22, CoOcMat_DifferenceVariance_22,			        ...
CoOcMat_FirstMeasureOfCorrelation_22, CoOcMat_SecondMeasureOfCorrelation_22,    ...
CoOcMat_MaximalCorrelationCoefficient_22] = magic_split(mb_texture(im_fft, 1, 90));

% Haralick Feature (Angle 135) 1 is 25
[CoOcMat_AngularSecondMoment_25, CoOcMat_Contrast_25, CoOcMat_Correlation_25, 	...				
CoOcMat_Variance_25, CoOcMat_InverseDifferenceMoment_25, CoOcMat_SumAverage_25,	...	
CoOcMat_SumVariance_25, CoOcMat_SumEntropy_25, CoOcMat_Entropy_25,				...	
CoOcMat_DifferenceEntropy_25, CoOcMat_DifferenceVariance_25,			        ...
CoOcMat_FirstMeasureOfCorrelation_25, CoOcMat_SecondMeasureOfCorrelation_25,    ...
CoOcMat_MaximalCorrelationCoefficient_25] = magic_split(mb_texture(im_fft, 1, 135));

%%
%% WavletLevel1 -> "Haralick Features (Angle X) 3"
%%

% Haralick Feature (Angle 0)   3 is 29
[CoOcMat_AngularSecondMoment_29, CoOcMat_Contrast_29, CoOcMat_Correlation_29, 	...				
CoOcMat_Variance_29, CoOcMat_InverseDifferenceMoment_29, CoOcMat_SumAverage_29,	...	
CoOcMat_SumVariance_29, CoOcMat_SumEntropy_29, CoOcMat_Entropy_29,				...	
CoOcMat_DifferenceEntropy_29, CoOcMat_DifferenceVariance_29,			        ...
CoOcMat_FirstMeasureOfCorrelation_29, CoOcMat_SecondMeasureOfCorrelation_29,    ...
CoOcMat_MaximalCorrelationCoefficient_29] = magic_split(mb_texture(im_wav1, 1, 0));

% Haralick Feature (Angle 45)  3 is 13
[CoOcMat_AngularSecondMoment_13, CoOcMat_Contrast_13, CoOcMat_Correlation_13, 	...				
CoOcMat_Variance_13, CoOcMat_InverseDifferenceMoment_13, CoOcMat_SumAverage_13, ...	
CoOcMat_SumVariance_13, CoOcMat_SumEntropy_13, CoOcMat_Entropy_13,				...	
CoOcMat_DifferenceEntropy_13, CoOcMat_DifferenceVariance_13,			        ...
CoOcMat_FirstMeasureOfCorrelation_13, CoOcMat_SecondMeasureOfCorrelation_13,    ...
CoOcMat_MaximalCorrelationCoefficient_13] = magic_split(mb_texture(im_wav1, 1, 45));

% Haralick Feature (Angle 90)  6 is 11
[CoOcMat_AngularSecondMoment_11, CoOcMat_Contrast_11, CoOcMat_Correlation_11, 	...				
CoOcMat_Variance_11, CoOcMat_InverseDifferenceMoment_11, CoOcMat_SumAverage_11,	...	
CoOcMat_SumVariance_11, CoOcMat_SumEntropy_11, CoOcMat_Entropy_11,				...	
CoOcMat_DifferenceEntropy_11, CoOcMat_DifferenceVariance_11,			        ...
CoOcMat_FirstMeasureOfCorrelation_11, CoOcMat_SecondMeasureOfCorrelation_11,    ...
CoOcMat_MaximalCorrelationCoefficient_11] = magic_split(mb_texture(im_wav1, 1, 90));


% Haralick Feature (Angle 135) 3 is 23
[CoOcMat_AngularSecondMoment_23, CoOcMat_Contrast_23, CoOcMat_Correlation_23, 	...				
CoOcMat_Variance_23, CoOcMat_InverseDifferenceMoment_23, CoOcMat_SumAverage_23,	...	
CoOcMat_SumVariance_23, CoOcMat_SumEntropy_23, CoOcMat_Entropy_23,				...	
CoOcMat_DifferenceEntropy_23, CoOcMat_DifferenceVariance_23,			        ...
CoOcMat_FirstMeasureOfCorrelation_23, CoOcMat_SecondMeasureOfCorrelation_23,    ...
CoOcMat_MaximalCorrelationCoefficient_23] = magic_split(mb_texture(im_wav1, 1, 135));


%%
%% Frequency -> WaveletLevel1 -> "Haralick Features (Angle X) 6"
%%

% Haralick Feature (Angle 0)   6 is 7
[CoOcMat_AngularSecondMoment_7, CoOcMat_Contrast_7, CoOcMat_Correlation_7, 		...			
CoOcMat_Variance_7, CoOcMat_InverseDifferenceMoment_7, CoOcMat_SumAverage_7,	...	
CoOcMat_SumVariance_7, CoOcMat_SumEntropy_7, CoOcMat_Entropy_7,					...
CoOcMat_DifferenceEntropy_7, CoOcMat_DifferenceVariance_7,			            ...
CoOcMat_FirstMeasureOfCorrelation_7, CoOcMat_SecondMeasureOfCorrelation_7,      ...
CoOcMat_MaximalCorrelationCoefficient_7] = magic_split(mb_texture(im_fft_wav1, 1, 0));

% Haralick Feature (Angle 45)  6 is 2
[CoOcMat_AngularSecondMoment_2, CoOcMat_Contrast_2, CoOcMat_Correlation_2, 		...			
CoOcMat_Variance_2, CoOcMat_InverseDifferenceMoment_2, CoOcMat_SumAverage_2,	...	
CoOcMat_SumVariance_2, CoOcMat_SumEntropy_2, CoOcMat_Entropy_2,					...
CoOcMat_DifferenceEntropy_2, CoOcMat_DifferenceVariance_2,			            ...
CoOcMat_FirstMeasureOfCorrelation_2, CoOcMat_SecondMeasureOfCorrelation_2,      ...
CoOcMat_MaximalCorrelationCoefficient_2] = magic_split(mb_texture(im_fft_wav1, 1, 45));

% Haralick Feature (Angle 90)  6 is 20
[CoOcMat_AngularSecondMoment_20, CoOcMat_Contrast_20, CoOcMat_Correlation_20, 	...				
CoOcMat_Variance_20, CoOcMat_InverseDifferenceMoment_20, CoOcMat_SumAverage_20,	...	
CoOcMat_SumVariance_20, CoOcMat_SumEntropy_20, CoOcMat_Entropy_20,				...	
CoOcMat_DifferenceEntropy_20, CoOcMat_DifferenceVariance_20,			        ...
CoOcMat_FirstMeasureOfCorrelation_20, CoOcMat_SecondMeasureOfCorrelation_20,    ...
CoOcMat_MaximalCorrelationCoefficient_20] = magic_split(mb_texture(im_fft_wav1, 1, 90));

% Haralick Feature (Angle 135) 6 is 30
[CoOcMat_AngularSecondMoment_30, CoOcMat_Contrast_30, CoOcMat_Correlation_30, 	...				
CoOcMat_Variance_30, CoOcMat_InverseDifferenceMoment_30, CoOcMat_SumAverage_30,	...	
CoOcMat_SumVariance_30, CoOcMat_SumEntropy_30, CoOcMat_Entropy_30,				...	
CoOcMat_DifferenceEntropy_30, CoOcMat_DifferenceVariance_30,			        ...
CoOcMat_FirstMeasureOfCorrelation_30, CoOcMat_SecondMeasureOfCorrelation_30,    ...
CoOcMat_MaximalCorrelationCoefficient_30] = magic_split(mb_texture(im_fft_wav1, 1, 135));

%%
%% WavletLevel2 -> "Haralick Features (Angle X) 5"
%%

% Haralick Feature (Angle 0)   5 is 5
[CoOcMat_AngularSecondMoment_5, CoOcMat_Contrast_5, CoOcMat_Correlation_5, 		...			
CoOcMat_Variance_5, CoOcMat_InverseDifferenceMoment_5, CoOcMat_SumAverage_5,	...	
CoOcMat_SumVariance_5, CoOcMat_SumEntropy_5, CoOcMat_Entropy_5,					...
CoOcMat_DifferenceEntropy_5, CoOcMat_DifferenceVariance_5,			            ...
CoOcMat_FirstMeasureOfCorrelation_5, CoOcMat_SecondMeasureOfCorrelation_5,      ...
CoOcMat_MaximalCorrelationCoefficient_5] = magic_split(mb_texture(im_wav2, 1, 0));

% Haralick Feature (Angle 45)  5 is 27
[CoOcMat_AngularSecondMoment_27, CoOcMat_Contrast_27, CoOcMat_Correlation_27, 	...				
CoOcMat_Variance_27, CoOcMat_InverseDifferenceMoment_27, CoOcMat_SumAverage_27,	...	
CoOcMat_SumVariance_27, CoOcMat_SumEntropy_27, CoOcMat_Entropy_27,				...	
CoOcMat_DifferenceEntropy_27, CoOcMat_DifferenceVariance_27,			        ...
CoOcMat_FirstMeasureOfCorrelation_27, CoOcMat_SecondMeasureOfCorrelation_27,    ...
CoOcMat_MaximalCorrelationCoefficient_27] = magic_split(mb_texture(im_wav2, 1, 45));

% Haralick Feature (Angle 90)  5 is 10
[CoOcMat_AngularSecondMoment_10, CoOcMat_Contrast_10, CoOcMat_Correlation_10, 	...				
CoOcMat_Variance_10, CoOcMat_InverseDifferenceMoment_10, CoOcMat_SumAverage_10,	...	
CoOcMat_SumVariance_10, CoOcMat_SumEntropy_10, CoOcMat_Entropy_10,				...	
CoOcMat_DifferenceEntropy_10, CoOcMat_DifferenceVariance_10,			        ...
CoOcMat_FirstMeasureOfCorrelation_10, CoOcMat_SecondMeasureOfCorrelation_10,    ...
CoOcMat_MaximalCorrelationCoefficient_10] = magic_split(mb_texture(im_wav2, 1, 90));

% Haralick Feature (Angle 135) 5 is 24
[CoOcMat_AngularSecondMoment_24, CoOcMat_Contrast_24, CoOcMat_Correlation_24, 	...				
CoOcMat_Variance_24, CoOcMat_InverseDifferenceMoment_24, CoOcMat_SumAverage_24,	...	
CoOcMat_SumVariance_24, CoOcMat_SumEntropy_24, CoOcMat_Entropy_24,				...	
CoOcMat_DifferenceEntropy_24, CoOcMat_DifferenceVariance_24,			        ...
CoOcMat_FirstMeasureOfCorrelation_24, CoOcMat_SecondMeasureOfCorrelation_24,    ...
CoOcMat_MaximalCorrelationCoefficient_24] = magic_split(mb_texture(im_wav2, 1, 135));


%%
%% Frequency -> WaveletLevel2 -> "Haralick Features (Angle X) 2"
%%

% Haralick Feature (Angle 0)   2 is 9
[CoOcMat_AngularSecondMoment_9, CoOcMat_Contrast_9, CoOcMat_Correlation_9, 		...			
CoOcMat_Variance_9, CoOcMat_InverseDifferenceMoment_9, CoOcMat_SumAverage_9,	...	
CoOcMat_SumVariance_9, CoOcMat_SumEntropy_9, CoOcMat_Entropy_9,					...
CoOcMat_DifferenceEntropy_9, CoOcMat_DifferenceVariance_9,			            ...
CoOcMat_FirstMeasureOfCorrelation_9, CoOcMat_SecondMeasureOfCorrelation_9,      ...
CoOcMat_MaximalCorrelationCoefficient_9] = magic_split(mb_texture(im_fft_wav2, 1, 0));

% Haralick Feature (Angle 45)  2 is 21
[CoOcMat_AngularSecondMoment_21, CoOcMat_Contrast_21, CoOcMat_Correlation_21, 	...				
CoOcMat_Variance_21, CoOcMat_InverseDifferenceMoment_21, CoOcMat_SumAverage_21,	...	
CoOcMat_SumVariance_21, CoOcMat_SumEntropy_21, CoOcMat_Entropy_21,				...	
CoOcMat_DifferenceEntropy_21, CoOcMat_DifferenceVariance_21,			        ...
CoOcMat_FirstMeasureOfCorrelation_21, CoOcMat_SecondMeasureOfCorrelation_21,    ...
CoOcMat_MaximalCorrelationCoefficient_21] = magic_split(mb_texture(im_fft_wav2, 1, 45));

% Haralick Feature (Angle 90)  2 is 12
[CoOcMat_AngularSecondMoment_12, CoOcMat_Contrast_12, CoOcMat_Correlation_12, 	...				
CoOcMat_Variance_12, CoOcMat_InverseDifferenceMoment_12, CoOcMat_SumAverage_12,	...	
CoOcMat_SumVariance_12, CoOcMat_SumEntropy_12, CoOcMat_Entropy_12,				...	
CoOcMat_DifferenceEntropy_12, CoOcMat_DifferenceVariance_12,			        ...
CoOcMat_FirstMeasureOfCorrelation_12, CoOcMat_SecondMeasureOfCorrelation_12,    ...
CoOcMat_MaximalCorrelationCoefficient_12] = magic_split(mb_texture(im_fft_wav2, 1, 90));

% Haralick Feature (Angle 135) 2 is 14
[CoOcMat_AngularSecondMoment_14, CoOcMat_Contrast_14, CoOcMat_Correlation_14, 	...				
CoOcMat_Variance_14, CoOcMat_InverseDifferenceMoment_14, CoOcMat_SumAverage_14,	...	
CoOcMat_SumVariance_14, CoOcMat_SumEntropy_14, CoOcMat_Entropy_14,				...	
CoOcMat_DifferenceEntropy_14, CoOcMat_DifferenceVariance_14,			        ...
CoOcMat_FirstMeasureOfCorrelation_14, CoOcMat_SecondMeasureOfCorrelation_14,    ...
CoOcMat_MaximalCorrelationCoefficient_14] = magic_split(mb_texture(im_fft_wav2, 1, 135));

%%
%% ChebyshevTransform -> "Haralick Features (Angle X) 7"
%%

% Haralick Feature (Angle 0)   7 is 4
[CoOcMat_AngularSecondMoment_4, CoOcMat_Contrast_4, CoOcMat_Correlation_4, 		...			
CoOcMat_Variance_4, CoOcMat_InverseDifferenceMoment_4, CoOcMat_SumAverage_4,	...	
CoOcMat_SumVariance_4, CoOcMat_SumEntropy_4, CoOcMat_Entropy_4,					...
CoOcMat_DifferenceEntropy_4, CoOcMat_DifferenceVariance_4,			            ...
CoOcMat_FirstMeasureOfCorrelation_4, CoOcMat_SecondMeasureOfCorrelation_4,      ...
CoOcMat_MaximalCorrelationCoefficient_4] = magic_split(mb_texture(im_ccm, 1, 0));

% Haralick Feature (Angle 45)  7 is 15
[CoOcMat_AngularSecondMoment_15, CoOcMat_Contrast_15, CoOcMat_Correlation_15, 	...				
CoOcMat_Variance_15, CoOcMat_InverseDifferenceMoment_15, CoOcMat_SumAverage_15,	...	
CoOcMat_SumVariance_15, CoOcMat_SumEntropy_15, CoOcMat_Entropy_15,				...	
CoOcMat_DifferenceEntropy_15, CoOcMat_DifferenceVariance_15,			        ...
CoOcMat_FirstMeasureOfCorrelation_15, CoOcMat_SecondMeasureOfCorrelation_15,    ...
CoOcMat_MaximalCorrelationCoefficient_15] = magic_split(mb_texture(im_ccm, 1, 45));

% Haralick Feature (Angle 90)  7 is 28
[CoOcMat_AngularSecondMoment_28, CoOcMat_Contrast_28, CoOcMat_Correlation_28, 	...				
CoOcMat_Variance_28, CoOcMat_InverseDifferenceMoment_28, CoOcMat_SumAverage_28,	...	
CoOcMat_SumVariance_28, CoOcMat_SumEntropy_28, CoOcMat_Entropy_28,				...	
CoOcMat_DifferenceEntropy_28, CoOcMat_DifferenceVariance_28,			        ...
CoOcMat_FirstMeasureOfCorrelation_28, CoOcMat_SecondMeasureOfCorrelation_28,    ...
CoOcMat_MaximalCorrelationCoefficient_28] = magic_split(mb_texture(im_ccm, 1, 90));

% Haralick Feature (Angle 135) 7 is 17
[CoOcMat_AngularSecondMoment_17, CoOcMat_Contrast_17, CoOcMat_Correlation_17, 	...				
CoOcMat_Variance_17, CoOcMat_InverseDifferenceMoment_17, CoOcMat_SumAverage_17,	...	
CoOcMat_SumVariance_17, CoOcMat_SumEntropy_17, CoOcMat_Entropy_17,				...	
CoOcMat_DifferenceEntropy_17, CoOcMat_DifferenceVariance_17,			        ...
CoOcMat_FirstMeasureOfCorrelation_17, CoOcMat_SecondMeasureOfCorrelation_17,    ...
CoOcMat_MaximalCorrelationCoefficient_17] = magic_split(mb_texture(im_ccm, 1, 135));

%%
%% Frequency -> ChebyshevTransform -> "Haralick Features (Angle X) 4"
%%

% Haralick Feature (Angle 0)   4 is 19
[CoOcMat_AngularSecondMoment_19, CoOcMat_Contrast_19, CoOcMat_Correlation_19, 	...				
CoOcMat_Variance_19, CoOcMat_InverseDifferenceMoment_19, CoOcMat_SumAverage_19,	...	
CoOcMat_SumVariance_19, CoOcMat_SumEntropy_19, CoOcMat_Entropy_19,				...	
CoOcMat_DifferenceEntropy_19, CoOcMat_DifferenceVariance_19,			        ...
CoOcMat_FirstMeasureOfCorrelation_19, CoOcMat_SecondMeasureOfCorrelation_19,    ...
CoOcMat_MaximalCorrelationCoefficient_19] = magic_split(mb_texture(im_ccm_fft, 1, 0));

% Haralick Feature (Angle 45)  4 is 3
[CoOcMat_AngularSecondMoment_3, CoOcMat_Contrast_3, CoOcMat_Correlation_3, 		...			
CoOcMat_Variance_3, CoOcMat_InverseDifferenceMoment_3, CoOcMat_SumAverage_3,	...	
CoOcMat_SumVariance_3, CoOcMat_SumEntropy_3, CoOcMat_Entropy_3,					...
CoOcMat_DifferenceEntropy_3, CoOcMat_DifferenceVariance_3,			            ...
CoOcMat_FirstMeasureOfCorrelation_3, CoOcMat_SecondMeasureOfCorrelation_3,      ...
CoOcMat_MaximalCorrelationCoefficient_3] = magic_split(mb_texture(im_ccm_fft, 1, 45));

% Haralick Feature (Angle 90)  4 is 1
[CoOcMat_AngularSecondMoment_1, CoOcMat_Contrast_1, CoOcMat_Correlation_1, 		...			
CoOcMat_Variance_1, CoOcMat_InverseDifferenceMoment_1, CoOcMat_SumAverage_1,	...	
CoOcMat_SumVariance_1, CoOcMat_SumEntropy_1, CoOcMat_Entropy_1,					...
CoOcMat_DifferenceEntropy_1, CoOcMat_DifferenceVariance_1,                      ...
CoOcMat_FirstMeasureOfCorrelation_1, CoOcMat_SecondMeasureOfCorrelation_1,      ...
CoOcMat_MaximalCorrelationCoefficient_1] = magic_split (mb_texture(im_ccm_fft, 1, 90));

% Haralick Feature (Angle 135) 4 is 8
[CoOcMat_AngularSecondMoment_8, CoOcMat_Contrast_8, CoOcMat_Correlation_8, 		...			
CoOcMat_Variance_8, CoOcMat_InverseDifferenceMoment_8, CoOcMat_SumAverage_8,	...	
CoOcMat_SumVariance_8, CoOcMat_SumEntropy_8, CoOcMat_Entropy_8,					...
CoOcMat_DifferenceEntropy_8, CoOcMat_DifferenceVariance_8,			            ...
CoOcMat_FirstMeasureOfCorrelation_8, CoOcMat_SecondMeasureOfCorrelation_8,      ...
CoOcMat_MaximalCorrelationCoefficient_8] = magic_split(mb_texture(im_ccm_fft, 1, 135));

sig_vec = ...
[ChebyshevCoefficientHistogram_1, ChebyshevCoefficientHistogram_2, ...
ChebyshevFourierCoefficients_1, ChebyshevFourierCoefficients_2,  ...
CoOcMat_AngularSecondMoment_1  CoOcMat_AngularSecondMoment_10 ...
CoOcMat_AngularSecondMoment_11 CoOcMat_AngularSecondMoment_12 ...
CoOcMat_AngularSecondMoment_13 CoOcMat_AngularSecondMoment_14 ...
CoOcMat_AngularSecondMoment_15 CoOcMat_AngularSecondMoment_16 ...
CoOcMat_AngularSecondMoment_17 CoOcMat_AngularSecondMoment_18 ...
CoOcMat_AngularSecondMoment_19 CoOcMat_AngularSecondMoment_2  ...
CoOcMat_AngularSecondMoment_20 CoOcMat_AngularSecondMoment_21 ...
CoOcMat_AngularSecondMoment_22 CoOcMat_AngularSecondMoment_23 ...
CoOcMat_AngularSecondMoment_24 CoOcMat_AngularSecondMoment_25 ...
CoOcMat_AngularSecondMoment_26 CoOcMat_AngularSecondMoment_27 ...
CoOcMat_AngularSecondMoment_28 CoOcMat_AngularSecondMoment_29 ...
CoOcMat_AngularSecondMoment_3  CoOcMat_AngularSecondMoment_30 ...
CoOcMat_AngularSecondMoment_31 CoOcMat_AngularSecondMoment_32 ...
CoOcMat_AngularSecondMoment_4  CoOcMat_AngularSecondMoment_5  ...
CoOcMat_AngularSecondMoment_6  CoOcMat_AngularSecondMoment_7  ...
CoOcMat_AngularSecondMoment_8  CoOcMat_AngularSecondMoment_9  ...
CoOcMat_Contrast_1  CoOcMat_Contrast_10 CoOcMat_Contrast_11  ...
CoOcMat_Contrast_12 CoOcMat_Contrast_13 CoOcMat_Contrast_14  ...
CoOcMat_Contrast_15 CoOcMat_Contrast_16 CoOcMat_Contrast_17  ...
CoOcMat_Contrast_18 CoOcMat_Contrast_19 CoOcMat_Contrast_2   ...
CoOcMat_Contrast_20 CoOcMat_Contrast_21 CoOcMat_Contrast_22  ...
CoOcMat_Contrast_23 CoOcMat_Contrast_24 CoOcMat_Contrast_25  ...
CoOcMat_Contrast_26 CoOcMat_Contrast_27 CoOcMat_Contrast_28  ...
CoOcMat_Contrast_29 CoOcMat_Contrast_3  CoOcMat_Contrast_30  ...
CoOcMat_Contrast_31 CoOcMat_Contrast_32 CoOcMat_Contrast_4   ...
CoOcMat_Contrast_5  CoOcMat_Contrast_6  CoOcMat_Contrast_7   ...
CoOcMat_Contrast_8  CoOcMat_Contrast_9                       ...
CoOcMat_Correlation_1  CoOcMat_Correlation_10 CoOcMat_Correlation_11 ...
CoOcMat_Correlation_12 CoOcMat_Correlation_13 CoOcMat_Correlation_14 ...
CoOcMat_Correlation_15 CoOcMat_Correlation_16 CoOcMat_Correlation_17 ...
CoOcMat_Correlation_18 CoOcMat_Correlation_19 CoOcMat_Correlation_2  ...
CoOcMat_Correlation_20 CoOcMat_Correlation_21 CoOcMat_Correlation_22 ...
CoOcMat_Correlation_23 CoOcMat_Correlation_24 CoOcMat_Correlation_25 ...
CoOcMat_Correlation_26 CoOcMat_Correlation_27 CoOcMat_Correlation_28 ...
CoOcMat_Correlation_29 CoOcMat_Correlation_3  CoOcMat_Correlation_30 ...
CoOcMat_Correlation_31 CoOcMat_Correlation_32 CoOcMat_Correlation_4  ...
CoOcMat_Correlation_5  CoOcMat_Correlation_6  CoOcMat_Correlation_7  ...
CoOcMat_Correlation_8  CoOcMat_Correlation_9                         ...
CoOcMat_DifferenceEntropy_1  CoOcMat_DifferenceEntropy_10 ...
CoOcMat_DifferenceEntropy_11 CoOcMat_DifferenceEntropy_12 ...
CoOcMat_DifferenceEntropy_13 CoOcMat_DifferenceEntropy_14 ...
CoOcMat_DifferenceEntropy_15 CoOcMat_DifferenceEntropy_16 ...
CoOcMat_DifferenceEntropy_17 CoOcMat_DifferenceEntropy_18 ...
CoOcMat_DifferenceEntropy_19 CoOcMat_DifferenceEntropy_2  ...
CoOcMat_DifferenceEntropy_20 CoOcMat_DifferenceEntropy_21 ...
CoOcMat_DifferenceEntropy_22 CoOcMat_DifferenceEntropy_23 ...
CoOcMat_DifferenceEntropy_24 CoOcMat_DifferenceEntropy_25 ...
CoOcMat_DifferenceEntropy_26 CoOcMat_DifferenceEntropy_27 ...
CoOcMat_DifferenceEntropy_28 CoOcMat_DifferenceEntropy_29 ...
CoOcMat_DifferenceEntropy_3  CoOcMat_DifferenceEntropy_30 ...
CoOcMat_DifferenceEntropy_31 CoOcMat_DifferenceEntropy_32 ...
CoOcMat_DifferenceEntropy_4  CoOcMat_DifferenceEntropy_5  ...
CoOcMat_DifferenceEntropy_6  CoOcMat_DifferenceEntropy_7  ...
CoOcMat_DifferenceEntropy_8  CoOcMat_DifferenceEntropy_9  ...
CoOcMat_DifferenceVariance_1  CoOcMat_DifferenceVariance_10 ...
CoOcMat_DifferenceVariance_11 CoOcMat_DifferenceVariance_12 ...
CoOcMat_DifferenceVariance_13 CoOcMat_DifferenceVariance_14 ...
CoOcMat_DifferenceVariance_15 CoOcMat_DifferenceVariance_16 ...
CoOcMat_DifferenceVariance_17 CoOcMat_DifferenceVariance_18 ...
CoOcMat_DifferenceVariance_19 CoOcMat_DifferenceVariance_2  ...
CoOcMat_DifferenceVariance_20 CoOcMat_DifferenceVariance_21 ...
CoOcMat_DifferenceVariance_22 CoOcMat_DifferenceVariance_23 ...
CoOcMat_DifferenceVariance_24 CoOcMat_DifferenceVariance_25 ...
CoOcMat_DifferenceVariance_26 CoOcMat_DifferenceVariance_27 ...
CoOcMat_DifferenceVariance_28 CoOcMat_DifferenceVariance_29 ...
CoOcMat_DifferenceVariance_3  CoOcMat_DifferenceVariance_30 ...
CoOcMat_DifferenceVariance_31 CoOcMat_DifferenceVariance_32 ...
CoOcMat_DifferenceVariance_4  CoOcMat_DifferenceVariance_5  ...
CoOcMat_DifferenceVariance_6  CoOcMat_DifferenceVariance_7  ...
CoOcMat_DifferenceVariance_8  CoOcMat_DifferenceVariance_9  ...
CoOcMat_Entropy_1  CoOcMat_Entropy_10 CoOcMat_Entropy_11 ...
CoOcMat_Entropy_12 CoOcMat_Entropy_13 CoOcMat_Entropy_14 ...
CoOcMat_Entropy_15 CoOcMat_Entropy_16 CoOcMat_Entropy_17 ...
CoOcMat_Entropy_18 CoOcMat_Entropy_19 CoOcMat_Entropy_2  ...
CoOcMat_Entropy_20 CoOcMat_Entropy_21 CoOcMat_Entropy_22 ...
CoOcMat_Entropy_23 CoOcMat_Entropy_24 CoOcMat_Entropy_25 ...
CoOcMat_Entropy_26 CoOcMat_Entropy_27 CoOcMat_Entropy_28 ...
CoOcMat_Entropy_29 CoOcMat_Entropy_3  CoOcMat_Entropy_30 ...
CoOcMat_Entropy_31 CoOcMat_Entropy_32 CoOcMat_Entropy_4  ...
CoOcMat_Entropy_5  CoOcMat_Entropy_6  CoOcMat_Entropy_7  ...
CoOcMat_Entropy_8  CoOcMat_Entropy_9 ...
CoOcMat_FirstMeasureOfCorrelation_1  CoOcMat_FirstMeasureOfCorrelation_10 ...
CoOcMat_FirstMeasureOfCorrelation_11 CoOcMat_FirstMeasureOfCorrelation_12 ...
CoOcMat_FirstMeasureOfCorrelation_13 CoOcMat_FirstMeasureOfCorrelation_14 ...
CoOcMat_FirstMeasureOfCorrelation_15 CoOcMat_FirstMeasureOfCorrelation_16 ...
CoOcMat_FirstMeasureOfCorrelation_17 CoOcMat_FirstMeasureOfCorrelation_18 ...
CoOcMat_FirstMeasureOfCorrelation_19 CoOcMat_FirstMeasureOfCorrelation_2  ...
CoOcMat_FirstMeasureOfCorrelation_20 CoOcMat_FirstMeasureOfCorrelation_21 ...
CoOcMat_FirstMeasureOfCorrelation_22 CoOcMat_FirstMeasureOfCorrelation_23 ...
CoOcMat_FirstMeasureOfCorrelation_24 CoOcMat_FirstMeasureOfCorrelation_25 ...
CoOcMat_FirstMeasureOfCorrelation_26 CoOcMat_FirstMeasureOfCorrelation_27 ...
CoOcMat_FirstMeasureOfCorrelation_28 CoOcMat_FirstMeasureOfCorrelation_29 ...
CoOcMat_FirstMeasureOfCorrelation_3  CoOcMat_FirstMeasureOfCorrelation_30 ...
CoOcMat_FirstMeasureOfCorrelation_31 CoOcMat_FirstMeasureOfCorrelation_32 ...
CoOcMat_FirstMeasureOfCorrelation_4  CoOcMat_FirstMeasureOfCorrelation_5  ...
CoOcMat_FirstMeasureOfCorrelation_6  CoOcMat_FirstMeasureOfCorrelation_7  ...
CoOcMat_FirstMeasureOfCorrelation_8  CoOcMat_FirstMeasureOfCorrelation_9  ...
CoOcMat_InverseDifferenceMoment_1  CoOcMat_InverseDifferenceMoment_10 ...
CoOcMat_InverseDifferenceMoment_11 CoOcMat_InverseDifferenceMoment_12 ...
CoOcMat_InverseDifferenceMoment_13 CoOcMat_InverseDifferenceMoment_14 ...
CoOcMat_InverseDifferenceMoment_15 CoOcMat_InverseDifferenceMoment_16 ...
CoOcMat_InverseDifferenceMoment_17 CoOcMat_InverseDifferenceMoment_18 ...
CoOcMat_InverseDifferenceMoment_19 CoOcMat_InverseDifferenceMoment_2  ...
CoOcMat_InverseDifferenceMoment_20 CoOcMat_InverseDifferenceMoment_21 ...
CoOcMat_InverseDifferenceMoment_22 CoOcMat_InverseDifferenceMoment_23 ...
CoOcMat_InverseDifferenceMoment_24 CoOcMat_InverseDifferenceMoment_25 ...
CoOcMat_InverseDifferenceMoment_26 CoOcMat_InverseDifferenceMoment_27 ...
CoOcMat_InverseDifferenceMoment_28 CoOcMat_InverseDifferenceMoment_29 ...
CoOcMat_InverseDifferenceMoment_3  CoOcMat_InverseDifferenceMoment_30 ...
CoOcMat_InverseDifferenceMoment_31 CoOcMat_InverseDifferenceMoment_32 ...
CoOcMat_InverseDifferenceMoment_4  CoOcMat_InverseDifferenceMoment_5  ...
CoOcMat_InverseDifferenceMoment_6  CoOcMat_InverseDifferenceMoment_7  ...
CoOcMat_InverseDifferenceMoment_8  CoOcMat_InverseDifferenceMoment_9  ...
CoOcMat_MaximalCorrelationCoefficient_1  CoOcMat_MaximalCorrelationCoefficient_10 ...
CoOcMat_MaximalCorrelationCoefficient_11 CoOcMat_MaximalCorrelationCoefficient_12 ...
CoOcMat_MaximalCorrelationCoefficient_13 CoOcMat_MaximalCorrelationCoefficient_14 ...
CoOcMat_MaximalCorrelationCoefficient_15 CoOcMat_MaximalCorrelationCoefficient_16 ...
CoOcMat_MaximalCorrelationCoefficient_17 CoOcMat_MaximalCorrelationCoefficient_18 ...
CoOcMat_MaximalCorrelationCoefficient_19 CoOcMat_MaximalCorrelationCoefficient_2  ...
CoOcMat_MaximalCorrelationCoefficient_20 CoOcMat_MaximalCorrelationCoefficient_21 ...
CoOcMat_MaximalCorrelationCoefficient_22 CoOcMat_MaximalCorrelationCoefficient_23 ...
CoOcMat_MaximalCorrelationCoefficient_24 CoOcMat_MaximalCorrelationCoefficient_25 ...
CoOcMat_MaximalCorrelationCoefficient_26 CoOcMat_MaximalCorrelationCoefficient_27 ...
CoOcMat_MaximalCorrelationCoefficient_28 CoOcMat_MaximalCorrelationCoefficient_29 ...
CoOcMat_MaximalCorrelationCoefficient_3  CoOcMat_MaximalCorrelationCoefficient_30 ...
CoOcMat_MaximalCorrelationCoefficient_31 CoOcMat_MaximalCorrelationCoefficient_32 ...
CoOcMat_MaximalCorrelationCoefficient_4  CoOcMat_MaximalCorrelationCoefficient_5  ...
CoOcMat_MaximalCorrelationCoefficient_6  CoOcMat_MaximalCorrelationCoefficient_7  ...
CoOcMat_MaximalCorrelationCoefficient_8  CoOcMat_MaximalCorrelationCoefficient_9  ...
CoOcMat_SecondMeasureOfCorrelation_1  CoOcMat_SecondMeasureOfCorrelation_10 ...
CoOcMat_SecondMeasureOfCorrelation_11 CoOcMat_SecondMeasureOfCorrelation_12 ...
CoOcMat_SecondMeasureOfCorrelation_13 CoOcMat_SecondMeasureOfCorrelation_14 ...
CoOcMat_SecondMeasureOfCorrelation_15 CoOcMat_SecondMeasureOfCorrelation_16 ...
CoOcMat_SecondMeasureOfCorrelation_17 CoOcMat_SecondMeasureOfCorrelation_18 ...
CoOcMat_SecondMeasureOfCorrelation_19 CoOcMat_SecondMeasureOfCorrelation_2  ...
CoOcMat_SecondMeasureOfCorrelation_20 CoOcMat_SecondMeasureOfCorrelation_21 ...
CoOcMat_SecondMeasureOfCorrelation_22 CoOcMat_SecondMeasureOfCorrelation_23 ...
CoOcMat_SecondMeasureOfCorrelation_24 CoOcMat_SecondMeasureOfCorrelation_25 ...
CoOcMat_SecondMeasureOfCorrelation_26 CoOcMat_SecondMeasureOfCorrelation_27 ...
CoOcMat_SecondMeasureOfCorrelation_28 CoOcMat_SecondMeasureOfCorrelation_29 ...
CoOcMat_SecondMeasureOfCorrelation_3  CoOcMat_SecondMeasureOfCorrelation_30 ...
CoOcMat_SecondMeasureOfCorrelation_31 CoOcMat_SecondMeasureOfCorrelation_32 ...
CoOcMat_SecondMeasureOfCorrelation_4  CoOcMat_SecondMeasureOfCorrelation_5  ...
CoOcMat_SecondMeasureOfCorrelation_6  CoOcMat_SecondMeasureOfCorrelation_7  ...
CoOcMat_SecondMeasureOfCorrelation_8  CoOcMat_SecondMeasureOfCorrelation_9  ...
CoOcMat_SumAverage_1  CoOcMat_SumAverage_10 CoOcMat_SumAverage_11  ...
CoOcMat_SumAverage_12 CoOcMat_SumAverage_13 CoOcMat_SumAverage_14  ...
CoOcMat_SumAverage_15 CoOcMat_SumAverage_16 CoOcMat_SumAverage_17  ...
CoOcMat_SumAverage_18 CoOcMat_SumAverage_19 CoOcMat_SumAverage_2   ...
CoOcMat_SumAverage_20 CoOcMat_SumAverage_21 CoOcMat_SumAverage_22  ...
CoOcMat_SumAverage_23 CoOcMat_SumAverage_24 CoOcMat_SumAverage_25  ...
CoOcMat_SumAverage_26 CoOcMat_SumAverage_27 CoOcMat_SumAverage_28  ...
CoOcMat_SumAverage_29 CoOcMat_SumAverage_3  CoOcMat_SumAverage_30  ...
CoOcMat_SumAverage_31 CoOcMat_SumAverage_32 CoOcMat_SumAverage_4   ...
CoOcMat_SumAverage_5  CoOcMat_SumAverage_6  CoOcMat_SumAverage_7   ...
CoOcMat_SumAverage_8  CoOcMat_SumAverage_9                         ...
CoOcMat_SumEntropy_1  CoOcMat_SumEntropy_10 CoOcMat_SumEntropy_11 ...
CoOcMat_SumEntropy_12 CoOcMat_SumEntropy_13 CoOcMat_SumEntropy_14 ...
CoOcMat_SumEntropy_15 CoOcMat_SumEntropy_16 CoOcMat_SumEntropy_17 ...
CoOcMat_SumEntropy_18 CoOcMat_SumEntropy_19 CoOcMat_SumEntropy_2  ...
CoOcMat_SumEntropy_20 CoOcMat_SumEntropy_21 CoOcMat_SumEntropy_22 ...
CoOcMat_SumEntropy_23 CoOcMat_SumEntropy_24 CoOcMat_SumEntropy_25 ...
CoOcMat_SumEntropy_26 CoOcMat_SumEntropy_27 CoOcMat_SumEntropy_28 ...
CoOcMat_SumEntropy_29 CoOcMat_SumEntropy_3  CoOcMat_SumEntropy_30 ...
CoOcMat_SumEntropy_31 CoOcMat_SumEntropy_32 CoOcMat_SumEntropy_4  ...
CoOcMat_SumEntropy_5  CoOcMat_SumEntropy_6  CoOcMat_SumEntropy_7  ...
CoOcMat_SumEntropy_8  CoOcMat_SumEntropy_9                        ...
CoOcMat_SumVariance_1  CoOcMat_SumVariance_10 CoOcMat_SumVariance_11 ...
CoOcMat_SumVariance_12 CoOcMat_SumVariance_13 CoOcMat_SumVariance_14 ...
CoOcMat_SumVariance_15 CoOcMat_SumVariance_16 CoOcMat_SumVariance_17 ...
CoOcMat_SumVariance_18 CoOcMat_SumVariance_19 CoOcMat_SumVariance_2  ...
CoOcMat_SumVariance_20 CoOcMat_SumVariance_21 CoOcMat_SumVariance_22 ...
CoOcMat_SumVariance_23 CoOcMat_SumVariance_24 CoOcMat_SumVariance_25 ...
CoOcMat_SumVariance_26 CoOcMat_SumVariance_27 CoOcMat_SumVariance_28 ...
CoOcMat_SumVariance_29 CoOcMat_SumVariance_3  CoOcMat_SumVariance_30 ...
CoOcMat_SumVariance_31 CoOcMat_SumVariance_32 CoOcMat_SumVariance_4  ...
CoOcMat_SumVariance_5  CoOcMat_SumVariance_6  CoOcMat_SumVariance_7  ...
CoOcMat_SumVariance_8  CoOcMat_SumVariance_9                         ...
CoOcMat_Variance_1  CoOcMat_Variance_10 CoOcMat_Variance_11 ...
CoOcMat_Variance_12 CoOcMat_Variance_13 CoOcMat_Variance_14 ...
CoOcMat_Variance_15 CoOcMat_Variance_16 CoOcMat_Variance_17 ...
CoOcMat_Variance_18 CoOcMat_Variance_19 CoOcMat_Variance_2  ...
CoOcMat_Variance_20 CoOcMat_Variance_21 CoOcMat_Variance_22 ...
CoOcMat_Variance_23 CoOcMat_Variance_24 CoOcMat_Variance_25 ...
CoOcMat_Variance_26 CoOcMat_Variance_27 CoOcMat_Variance_28 ...
CoOcMat_Variance_29 CoOcMat_Variance_3  CoOcMat_Variance_30 ...
CoOcMat_Variance_31 CoOcMat_Variance_32 CoOcMat_Variance_4  ...
CoOcMat_Variance_5  CoOcMat_Variance_6  CoOcMat_Variance_7  ...
CoOcMat_Variance_8  CoOcMat_Variance_9 ...
EdgeArea EdgeDiffDirecHist EdgeDirecHist EdgeDirecHomo EdgeDirecMean ...
EdgeDirecMedian EdgeDirecVar EdgeMagHist EdgeMagMean EdgeMagMedian ...
EdgeMagVar ...
FeatureAreaHist FeatureAreaMax FeatureAreaMean FeatureAreaMedian ...
FeatureAreaMin FeatureAreaVar FeatureCentroid FeatureCount FeatureDistHist ...
FeatureDistMax FeatureDistMean FeatureDistMedian FeatureDistMin ...
FeatureDistVar FeatureEuler ...
ZernikeMoments]';

%
% Helper function converts the Haralick Vector into a bunch of singlton Attributes
%
function ...
[CoOcMat_AngularSecondMoment CoOcMat_Contrast CoOcMat_Correlation 	...				
CoOcMat_Variance CoOcMat_InverseDifferenceMoment CoOcMat_SumAverage	...
CoOcMat_SumVariance CoOcMat_SumEntropy CoOcMat_Entropy				...
CoOcMat_DifferenceEntropy CoOcMat_DifferenceVariance			        ...
CoOcMat_FirstMeasureOfCorrelation CoOcMat_SecondMeasureOfCorrelation  ...
CoOcMat_MaximalCorrelationCoefficient] = magic_split(vec);

CoOcMat_AngularSecondMoment           = vec(1);
CoOcMat_Contrast                      = vec(2);
CoOcMat_Correlation                   = vec(3);				
CoOcMat_Variance                      = vec(4);
CoOcMat_InverseDifferenceMoment       = vec(5);
CoOcMat_SumAverage                    = vec(6);
CoOcMat_SumVariance                   = vec(7);
CoOcMat_SumEntropy                    = vec(8);
CoOcMat_Entropy                       = vec(9);
CoOcMat_DifferenceEntropy             = vec(10);
CoOcMat_DifferenceVariance            = vec(11);
CoOcMat_FirstMeasureOfCorrelation     = vec(12);
CoOcMat_SecondMeasureOfCorrelation    = vec(13);
CoOcMat_MaximalCorrelationCoefficient = vec(14);

