# OME/Web/DBObjDetail/__OME_Image.pm

#-------------------------------------------------------------------------------
#
# Copyright (C) 2003 Open Microscopy Environment
#       Massachusetts Institute of Technology,
#       National Institutes of Health,
#       University of Dundee
#
#
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#-------------------------------------------------------------------------------




#-------------------------------------------------------------------------------
#
# Written by:    Josiah Johnston <siah@nih.gov>
#
#-------------------------------------------------------------------------------


package OME::Web::DBObjDetail::__OME_Image;

=pod

=head1 NAME

OME::Web::DBObjDetail::__OME_Image

=head1 DESCRIPTION

Allow description and annotation of the image to be changed.

=cut

#*********
#********* INCLUDES
#*********

use strict;
use OME;
our $VERSION = $OME::VERSION;
use Log::Agent;
use OME::Tasks::ImageManager;
use base qw(OME::Web::DBObjDetail);

sub _takeAction {
	my $self = shift;
	my $image = $self->_loadObject();
	my $q = $self->CGI();

	if( $q->param( 'action' ) eq 'SaveDescription' ) {
		$image->description( $q->param( 'description' ) );
		$image->storeObject();
		$self->Session()->commitTransaction();
	}

	if( $q->param( 'action' ) eq 'SaveAnnotation' ) {
		OME::Tasks::ImageManager->writeAnnotation(
			$image, { Content => $q->param( 'annotation' ) }
		);
		$self->Session()->commitTransaction();
	}

	if( $q->param( 'action' ) eq 'DeleteAnnotation' ) {
		OME::Tasks::ImageManager->deleteCurrentAnnotation( $image );
		$self->Session()->commitTransaction();
	}

}

=head1 Author

Josiah Johnston <siah@nih.gov>

=cut

1;
